==> enchdesc-fabric-1.21.3-21.3.1-sources.jar: net/darkhax/enchdesc/common/mixin/patch/MixinItemEnchants.java <==
package net.darkhax.enchdesc.common.mixin.patch;

import it.unimi.dsi.fastutil.objects.Object2IntMap;
import it.unimi.dsi.fastutil.objects.ObjectIterator;
import net.darkhax.enchdesc.common.api.ContextProvider;
import net.darkhax.enchdesc.common.impl.EnchantmentDescriptionsMod;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1836;
import net.minecraft.class_1887;
import net.minecraft.class_2561;
import net.minecraft.class_6880;
import net.minecraft.class_6885;
import net.minecraft.class_7225;
import net.minecraft.class_9304;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Unique;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import org.spongepowered.asm.mixin.injection.callback.LocalCapture;

import java.util.Iterator;
import java.util.function.Consumer;

@Mixin(class_9304.class)
public class MixinItemEnchants implements ContextProvider {

    @Unique
    private class_1799 enchdesc$heldStack = class_1799.field_8037;

    @Override
    public class_1799 enchdesc$getStack() {
        return enchdesc$heldStack;
    }

    @Override
    public void enchdesc$setStack(class_1799 stack) {
        this.enchdesc$heldStack = stack;
    }

    @Inject(method = "addToTooltip", at = @At(value = "INVOKE", target = "Ljava/util/function/Consumer;accept(Ljava/lang/Object;)V", ordinal = 0, shift = At.Shift.AFTER), locals = LocalCapture.CAPTURE_FAILHARD)
    public void sortedEnchantment(class_1792.class_9635 context, Consumer<class_2561> tooltips, class_1836 flag, CallbackInfo cbi, class_7225.class_7874 lookup, class_6885<class_1887> sorted, Iterator<class_6880<class_1887>> iter, class_6880<class_1887> enchantment, int level) {
        if (!this.enchdesc$heldStack.method_7960()) {
            EnchantmentDescriptionsMod.insertDescriptions(enchantment, level, tooltips);
        }
    }

    @Inject(method = "addToTooltip", at = @At(value = "INVOKE", target = "Ljava/util/function/Consumer;accept(Ljava/lang/Object;)V", ordinal = 1, shift = At.Shift.AFTER), locals = LocalCapture.CAPTURE_FAILHARD)
    public void unsortedEnchantment(class_1792.class_9635 context, Consumer<class_2561> tooltips, class_1836 flag, CallbackInfo cbi, class_7225.class_7874 lookup, class_6885<class_1887> sorted, ObjectIterator<class_6880<class_1887>> iter, Object2IntMap.Entry<class_6880<class_1887>> entry, class_6880<class_1887> enchantment) {
        if (!this.enchdesc$heldStack.method_7960()) {
            EnchantmentDescriptionsMod.insertDescriptions(enchantment, entry.getIntValue(), tooltips);
        }
    }
}

==> enchdesc-fabric-1.21.4-21.4.1-sources.jar: net/darkhax/enchdesc/common/mixin/patch/MixinItemEnchants.java <==
package net.darkhax.enchdesc.common.mixin.patch;

import it.unimi.dsi.fastutil.objects.Object2IntMap;
import it.unimi.dsi.fastutil.objects.ObjectIterator;
import net.darkhax.enchdesc.common.impl.EnchantmentDescriptionsMod;
import net.minecraft.class_1792;
import net.minecraft.class_1836;
import net.minecraft.class_1887;
import net.minecraft.class_2561;
import net.minecraft.class_6880;
import net.minecraft.class_6885;
import net.minecraft.class_7225;
import net.minecraft.class_9304;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import org.spongepowered.asm.mixin.injection.callback.LocalCapture;

import java.util.Iterator;
import java.util.function.Consumer;

@Mixin(class_9304.class)
public class MixinItemEnchants {

    @Inject(method = "addToTooltip", at = @At(value = "INVOKE", target = "Ljava/util/function/Consumer;accept(Ljava/lang/Object;)V", ordinal = 0, shift = At.Shift.AFTER), locals = LocalCapture.CAPTURE_FAILHARD)
    public void sortedEnchantment(class_1792.class_9635 context, Consumer<class_2561> tooltips, class_1836 flag, CallbackInfo cbi, class_7225.class_7874 lookup, class_6885<class_1887> sorted, Iterator<class_6880<class_1887>> iter, class_6880<class_1887> enchantment, int level) {
        EnchantmentDescriptionsMod.insertDescriptions(enchantment, level, tooltips);
    }

    @Inject(method = "addToTooltip", at = @At(value = "INVOKE", target = "Ljava/util/function/Consumer;accept(Ljava/lang/Object;)V", ordinal = 1, shift = At.Shift.AFTER), locals = LocalCapture.CAPTURE_FAILHARD)
    public void unsortedEnchantment(class_1792.class_9635 context, Consumer<class_2561> tooltips, class_1836 flag, CallbackInfo cbi, class_7225.class_7874 lookup, class_6885<class_1887> sorted, ObjectIterator<class_6880<class_1887>> iter, Object2IntMap.Entry<class_6880<class_1887>> entry, class_6880<class_1887> enchantment) {
        EnchantmentDescriptionsMod.insertDescriptions(enchantment, entry.getIntValue(), tooltips);
    }
}
